@@ -5,12 +5,12 @@
 Language
 </category>
 
-<name>  
+<name>
 Norwegian
 </name>
 
 <description>  
-Norwegian Language Meta-Package
+Norwegian dictionary for hunspell
 </description>
 
 <installable>
@@ -25,8 +25,7 @@ echo "---- preprocessing done----"
 </preinstall>
 
 <install_package_names>
-aspell-no
-myspell-nb
+hunspell-no
 </install_package_names>
 
 <postinstall>
@@ -34,8 +33,7 @@ myspell-nb
 </postinstall>
 
 <uninstall_package_names>
-aspell-no
-myspell-nb
+hunspell-no
 </uninstall_package_names>
 
 </app>
